@@ -91,6 +91,8 @@ nepim_global_t nepim_global = {
   0,        /* udp_dst_random_addr (0=fixed,1=random) */
   0,        /* udp_dst_random_port (0=fixed,1=random) */
   0,        /* report_partial_min_max (boolean) */
+  -1,       /* client_tcp_mss */
+  -1,       /* server_tcp_mss */
 
   0, /* oop source */
   0  /* source interface */
