@@ -96,6 +96,8 @@ struct nepim_global_t {
   int           udp_dst_random_addr;   /* 0=fixed,1=random */
   int           udp_dst_random_port;   /* 0=fixed,1=random */
   int           report_partial_min_max; /* boolean */
+  int           client_tcp_mss; /* bytes */
+  int           server_tcp_mss; /* bytes */
 
   oop_source_sys *oop_sys;
   oop_source     *oop_src;
