@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: greet.c,v 1.22 2007/10/19 20:10:18 evertonm Exp $ */
+/* $Id: greet.c,v 1.23 2008/03/27 20:57:19 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -52,6 +52,7 @@ const char *GREET_SWEEP_STEP        = "sweep_step=";
 const char *GREET_WRITE_FLOOR       = "write_floor=";
 const char *GREET_WRITE_CEIL        = "write_ceil=";
 const char *GREET_PARTIAL_MINMAX    = "partial_minmax=";
+const char *GREET_MSS               = "mss=";
 const char *GREET_PASSWORD          = "password=";
 
 #define NEPIM_GREET_PARSE_OK     (0)
@@ -81,6 +82,7 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
 		" %s%d %s%d %s%d"
 		" %s%d %s%d %s%d %s%d"
 		" %s%d"
+		" %s%d"
 		" %s%s\n", 
                 GREET_SERVER_SEND,       opt->must_send,
                 GREET_BIT_RATE,          opt->bit_rate,
@@ -105,6 +107,7 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
 		GREET_WRITE_FLOOR,       opt->write_floor,
 		GREET_WRITE_CEIL,        opt->write_ceil,
 		GREET_PARTIAL_MINMAX,    opt->report_partial_min_max,
+		GREET_MSS,               opt->mss,
                 GREET_PASSWORD,          opt->password_buf);
 
   if (pr < 1)
@@ -149,6 +152,7 @@ int nepim_parse_greetings(nepim_greet_t *opt, int is_tcp,
   const int GREET_WRITE_FLOOR_LEN       = strlen(GREET_WRITE_FLOOR);
   const int GREET_WRITE_CEIL_LEN        = strlen(GREET_WRITE_CEIL);
   const int GREET_PARTIAL_MINMAX_LEN    = strlen(GREET_PARTIAL_MINMAX);
+  const int GREET_MSS_LEN               = strlen(GREET_MSS);
   const int GREET_PASSWORD_LEN          = strlen(GREET_PASSWORD);
 
   int       server_send       = -2;
@@ -174,6 +178,7 @@ int nepim_parse_greetings(nepim_greet_t *opt, int is_tcp,
   int       write_floor       = -2;
   int       write_ceil        = -2;
   int       partial_minmax    = -2;
+  int       mss               = -2;
 
   assert(opt->password_buf);
   assert(opt->password_buf_size > 0);
@@ -318,6 +323,11 @@ int nepim_parse_greetings(nepim_greet_t *opt, int is_tcp,
       continue;
     }
 
+    if (!strncmp(tok, GREET_MSS, GREET_MSS_LEN)) {
+      mss = atoi(tok + GREET_MSS_LEN);
+      continue;
+    }
+
     if (!strncmp(tok, GREET_PASSWORD, GREET_PASSWORD_LEN)) {
       const char *tmp_past_end = tmp + sizeof(tmp);
       const char *pass;
@@ -400,6 +410,7 @@ int nepim_parse_greetings(nepim_greet_t *opt, int is_tcp,
   opt->write_floor            = write_floor;
   opt->write_ceil             = write_ceil;
   opt->report_partial_min_max = (partial_minmax == -2) ? 0 : partial_minmax;
+  opt->mss                    = mss;
 
   return NEPIM_GREET_PARSE_OK;
 }
