@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.71 2008/02/15 14:42:41 evertonm Exp $
+  $Id: main.c,v 1.72 2008/03/27 20:57:19 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -94,6 +94,7 @@ static void usage(FILE *out, const char *prog_name)
           "                         1 = WANT (use per-route hints)\n"
           "                         2 = DO   (always do PMTU discovery, DF=1)\n"
           "  -t ttl         TTL for sending packets (defaults to system)\n"
+          "  -smss bytes    set server-side TCP maximum segment size (MSS)\n"
           "  -w size        TCP write size (defaults to %d bytes)\n"
           "  -z size        TCP read size (defaults to %d bytes)\n"
           "  -W size        UDP write size (defaults to %d bytes)\n"
@@ -150,6 +151,7 @@ static void usage(FILE *out, const char *prog_name)
 	  "                 'interval' can't be lower than %ld us\n"
 	  "  -K udp-ka-time UDP keepalive timeout (defaults to %ld us)\n"
 	  "                 'udp-ka-time' can't be lower than %ld us\n"
+	  "  -cmss bytes    set client-side TCP maximum segment size (MSS)\n"
 	  "  -mM            report periodic (per-interval) min-MAX rates\n"
 	  "  -N nagle       TCP nagle mode (defaults to %d)\n"
 	  "                 nagle: -1 = use system's default\n"
@@ -661,6 +663,28 @@ int main(int argc, const char *argv[])
       continue;
     }
 
+    if (!strcmp(arg, "-cmss")) {
+      ++i;
+      if (i >= argc) {
+        fprintf(stderr, "%s: missing client TCP MSS\n",
+                nepim_global.prog_name);
+        exit(1);
+      }
+      nepim_global.client_tcp_mss = atoi(argv[i]);
+      continue;
+    }
+
+    if (!strcmp(arg, "-smss")) {
+      ++i;
+      if (i >= argc) {
+        fprintf(stderr, "%s: missing server TCP MSS\n",
+                nepim_global.prog_name);
+        exit(1);
+      }
+      nepim_global.server_tcp_mss = atoi(argv[i]);
+      continue;
+    }
+
     if (!strncmp(arg, "-F", 2)) {
       nepim_global.udp_mode                = 1; /* -u (UDP) */
       nepim_global.simplex_client_send     = 1; /* -s (client-send) */
