@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.81 2007/10/18 21:51:44 evertonm Exp $ */
+/* $Id: server.c,v 1.82 2008/03/27 20:57:19 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -439,7 +439,8 @@ static int parse_greetings(int sd,
           "seed=0x%08x verify_data=%d random_fill=%d fill_byte=0x%02x pause_duration=%d "
           "sock_ka=%d nagle=%d overhead=%d "
 	  "sweep_random=%d sweep_step=%d write_floor=%d write_ceil=%d "
-	  "p_minmax=%d password=%s\n", 
+	  "p_minmax=%d mss=%d "
+	  "password=%s\n", 
           sd, opt.must_send, opt.bit_rate, opt.pkt_rate,
           opt.stat_interval, opt.test_duration, 
           opt.write_delay, opt.keepalive_must_send,
@@ -448,7 +449,7 @@ static int parse_greetings(int sd,
           opt.verify_data, opt.random_fill, opt.fill_byte, opt.pause_duration,
 	  opt.socket_keepalive, opt.nagle, opt.overhead,
 	  opt.sweep_random, opt.sweep_step, opt.write_floor, opt.write_ceil,
-	  opt.report_partial_min_max,
+	  opt.report_partial_min_max, opt.mss,
           password_buf);
 
   nepim_conf_write_sweep_auto(0 /* udp=false */,
@@ -477,7 +478,8 @@ static int parse_greetings(int sd,
   nodelay = (opt.nagle == -1) ? -1 : !opt.nagle;
 
   result = nepim_socket_tcp_opt(nepim_global.verbose_stderr,
-				sockaddr_family, sd, nodelay);
+				sockaddr_family, sd, nodelay,
+				opt.mss);
   if (result) {
     fprintf(stderr, 
             "%d: %s: %s: could not set tcp options: %d\n",
@@ -1028,7 +1030,8 @@ static int spawn_tcp_listener(const char *hostname, const char *portname)
                                       nepim_global.win_recv,
                                       nepim_global.win_send,
 				      nodelay,
-				      nepim_global.tos);
+				      nepim_global.tos,
+				      nepim_global.server_tcp_mss);
     if (sd < 0) {
       fprintf(stderr, 
               "%s %s: TCP listener socket failed for %s,%d: %d\n",
@@ -1087,7 +1090,8 @@ static int spawn_unix_listener(const char *path)
 				    nepim_global.win_recv,
 				    nepim_global.win_send,
 				    nodelay,
-				    nepim_global.tos);
+				    nepim_global.tos,
+				    nepim_global.server_tcp_mss);
   if (sd < 0) {
     fprintf(stderr, 
 	    "%s %s: UNIX stream listener socket failed for path=%s\n",
