@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: slot.c,v 1.50 2007/08/17 18:28:25 evertonm Exp $ */
+/* $Id: slot.c,v 1.51 2007/10/22 16:08:46 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -254,7 +254,15 @@ int nepim_slot_buf_sendto(nepim_slot_t *slot, char *buf, size_t buf_size, uint8_
 	int i;
 	for (i = 0; i < 4; ++i) {
 	  uint32_t random_addr = nepim_urand_next(&slot->session.udp_dst_random_ctx);
+#ifdef HAVE_INET6_IN6_U /* Linux */
 	  slot->session.remote.inet6.sin6_addr.in6_u.u6_addr32[i] = random_addr;
+#elif HAVE_INET6_S6_UN /* Solaris */
+	  slot->session.remote.inet6.sin6_addr._S6_un._S6_u32[i] = random_addr;
+#elif HAVE_INET6_U6_ADDR /* FreeBSD */
+          slot->session.remote.inet6.sin6_addr.__u6_addr.__u6_addr32[i] = random_addr;
+#else
+          assert(0);	
+#endif
 	}
       }
       break;
