@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: sock.c,v 1.43 2007/08/31 14:47:34 evertonm Exp $ */
+/* $Id: sock.c,v 1.44 2008/03/27 20:57:19 evertonm Exp $ */
 
 #include <assert.h>
 #include <netdb.h>
@@ -343,7 +343,7 @@ static const char *proto_name(int proto)
 
 static int create_socket(FILE *err, int domain, int type, int protocol,
 			 int pmtu_mode, int ttl, int win_recv,
-			 int win_send, int nodelay, int tos)
+			 int win_send, int nodelay, int tos, int mss)
 {
   int sd;
   int result;
@@ -363,7 +363,7 @@ static int create_socket(FILE *err, int domain, int type, int protocol,
   }
 
   if (type == SOCK_STREAM) {
-    result = nepim_socket_tcp_opt(err, domain, sd, nodelay);
+    result = nepim_socket_tcp_opt(err, domain, sd, nodelay, mss);
     if (result) {
       close(sd);
       return result;
@@ -445,13 +445,14 @@ int nepim_create_socket(FILE *err,
 			int win_recv,
 			int win_send,
 			int nodelay,
-			int tos)
+			int tos,
+			int mss)
 {
   int sd;
   int result;
 
   sd = create_socket(err, family, type, protocol, pmtu_mode, ttl,
-		     win_recv, win_send, nodelay, tos);
+		     win_recv, win_send, nodelay, tos, mss);
   if (sd < 0)
     return sd;
 
@@ -526,14 +527,15 @@ int nepim_create_listener_socket(FILE *err,
 				 int win_recv,
 				 int win_send,
 				 int nodelay,
-				 int tos)
+				 int tos,
+				 int mss)
 {
   int sd;
 
   sd = nepim_create_socket(err, addr, addr_len, family,
 			   type, protocol, pmtu_mode, 
 			   ttl, 0, win_recv, win_send,
-			   nodelay, tos);
+			   nodelay, tos, mss);
   if (sd < 0)
     return sd;
 
@@ -633,7 +635,31 @@ int nepim_socket_opt(FILE *err, int sd, int pmtu_mode, int ttl, int tos)
   return NEPIM_SOCK_ERR_NONE;
 }
 
-int nepim_socket_tcp_opt(FILE *err, int family, int sd, int nodelay)
+static int nepim_socket_mss(FILE *err, int sd, int mss)
+{
+  if (mss < 0)
+    return NEPIM_SOCK_ERR_NONE;
+
+  if (err)
+    fprintf(err, "%s: %s: setsockopt(%d, SOL_TCP, TCP_MAXSEG, %d)\n",
+	    __FILE__, __PRETTY_FUNCTION__, sd, mss);
+
+  if (setsockopt(sd, SOL_TCP, TCP_MAXSEG, &mss, sizeof(mss))) {
+
+    if (err) {
+      int e = errno;
+      fprintf(err, "%s: %s: setsockopt: TCP_MAXSEG: mss=%d: sd=%d: errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      mss, sd, e, strerror(e));
+    }
+
+    return NEPIM_SOCK_ERR_MSS;
+  }
+
+  return NEPIM_SOCK_ERR_NONE;
+}
+
+int nepim_socket_tcp_opt(FILE *err, int family, int sd, int nodelay, int mss)
 {
   if (set_tcp_nodelay(err, sd, nodelay)) {
     /*
@@ -643,6 +669,14 @@ int nepim_socket_tcp_opt(FILE *err, int family, int sd, int nodelay)
       return NEPIM_SOCK_ERR_NODELAY;
   }
 
+  if (nepim_socket_mss(err, sd, mss)) {
+    /*
+      Tolerate failure in setting TCP_MAXSEG for PF_UNIX sockets
+    */
+    if (family != PF_UNIX)
+      return NEPIM_SOCK_ERR_MSS;
+  }
+
   return NEPIM_SOCK_ERR_NONE;
 }
 
@@ -702,7 +736,8 @@ int nepim_connect_client_socket(FILE *err,
 				int win_send,
 				int nodelay,
 				int tos,
-				int socket_keepalive)
+				int socket_keepalive,
+				int mss)
 {
   int sd;
   int result;
@@ -710,7 +745,7 @@ int nepim_connect_client_socket(FILE *err,
   sd = nepim_create_socket(err, bind, bind_len,
 			   family, type, protocol, pmtu_mode, ttl,
 			   0 /* mcast_join: false */,
-			   win_recv, win_send, nodelay, tos);
+			   win_recv, win_send, nodelay, tos, mss);
   if (sd < 0)
     return sd;
 
