@@ -30,7 +30,7 @@ int nepim_socket_ttl(int sd, int ttl);
 int nepim_socket_mcast_ttl(int sd, int mcast_ttl);
 int nepim_socket_pmtu(int sd, int pmtu_mode);
 int nepim_socket_opt(FILE *err, int sd, int pmtu_mode, int ttl, int tos);
-int nepim_socket_tcp_opt(FILE *err, int family, int sd, int nodelay);
+int nepim_socket_tcp_opt(FILE *err, int family, int sd, int nodelay, int mss);
 int nepim_socket_keepalive(FILE *err, int sd, int keepalive);
 
 int nepim_socket_pmtu_get_mode(int sd);
@@ -49,7 +49,8 @@ int nepim_create_socket(FILE *err,
 			int win_recv,
 			int win_send,
 			int nodelay,
-			int tos);
+			int tos,
+			int mss);
 int nepim_create_listener_socket(FILE *err,
 				 struct sockaddr *addr,
 				 int addr_len,
@@ -62,7 +63,8 @@ int nepim_create_listener_socket(FILE *err,
 				 int win_recv,
 				 int win_send,
 				 int nodelay,
-				 int tos);
+				 int tos,
+				 int mss);
 int nepim_connect_client_socket(FILE *err,
 				const struct sockaddr *bind, int bind_len,
 				struct sockaddr *addr, int addr_len,
@@ -75,7 +77,8 @@ int nepim_connect_client_socket(FILE *err,
 				int win_send,
 				int nodelay,
 				int tos,
-				int socket_keepalive);
+				int socket_keepalive,
+				int mss);
 
 int nepim_sock_get_port(const struct sockaddr *addr);
 void nepim_sock_set_port(const struct sockaddr *addr, int port);
