@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.84 2007/10/18 21:51:44 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.85 2008/03/27 20:57:20 evertonm Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -428,6 +428,7 @@ static int slot_greet_write(nepim_slot_t *slot)
   opt.write_floor             = nepim_global.server_write_floor;
   opt.write_ceil              = nepim_global.server_write_ceil;
   opt.report_partial_min_max  = nepim_global.report_partial_min_max;
+  opt.mss                     = nepim_global.server_tcp_mss;
 
   if (nepim_global.password) {
     opt.password_buf      = (char *) nepim_global.password;
@@ -1306,7 +1307,8 @@ static int spawn_udp_connection(const char *hostport,
                                      nepim_global.win_send,
 				     0 /* tcp nodelay */,
 				     nepim_global.tos,
-				     nepim_global.socket_keepalive);
+				     nepim_global.socket_keepalive,
+				     nepim_global.client_tcp_mss);
     if (sd < 0) {
       if (ai->ai_family == AF_UNIX)
 	fprintf(stderr, 
