@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.107 2007/10/18 21:51:44 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.108 2008/03/27 20:57:20 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -812,7 +812,8 @@ static int parse_greetings(nepim_greet_t *opt,
           "seed=0x%08x verify_data=%d random_fill=%d fill_byte=0x%02x pause_duration=%d "
 	  "sock_ka=%d overhead=%d "
 	  "sweep_random=%d sweep_step=%d write_floor=%d write_ceil=%d "
-	  "p_minmax=%d password=%s\n", 
+	  "p_minmax=%d mss=%d "
+	  "password=%s\n", 
 	  sd, 
 	  local_slot, remote_slot,
 	  peer,
@@ -826,7 +827,7 @@ static int parse_greetings(nepim_greet_t *opt,
 	  opt->pause_duration, opt->socket_keepalive,
 	  opt->overhead,
 	  opt->sweep_random, opt->sweep_step, opt->write_floor, opt->write_ceil,
-	  opt->report_partial_min_max,
+	  opt->report_partial_min_max, opt->mss,
 	  password_buf);
 
   nepim_conf_write_sweep_auto(1 /* udp=true */,
@@ -1137,7 +1138,8 @@ int nepim_udp_listener(const char *hostname, const char *portname,
 			     nepim_global.win_recv,
 			     nepim_global.win_send,
 			     0 /* tcp nodelay */,
-			     nepim_global.tos);
+			     nepim_global.tos,
+			     nepim_global.server_tcp_mss);
     if (sd < 0) {
       fprintf(stderr, 
               "%s %s: UDP listener socket failed for %s,%d: %d\n",
@@ -1197,7 +1199,8 @@ int nepim_unix_dgram_listener(const char *path)
 			   nepim_global.win_recv,
 			   nepim_global.win_send,
 			   0 /* tcp nodelay */,
-			   nepim_global.tos);
+			   nepim_global.tos,
+			   nepim_global.server_tcp_mss);
   if (sd < 0) {
     fprintf(stderr, 
 	    "%s %s: UNIX datagram listener socket failed for path=%s\n",
